@@ -10,7 +10,7 @@
 // ==========================================================================
 //
 // High-Performance Connectivity Tracer (HiPerConTracer)
-// Copyright (C) 2015-2025 by Thomas Dreibholz
+// Copyright (C) 2015-2026 by Thomas Dreibholz
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 
 #include "logger.h"
 
+#include "package-version.h"
 // #include "reader-jitter.h"
 #include "reader-ping.h"
 #include "reader-traceroute.h"
@@ -68,6 +69,8 @@ int main(int argc, char** argv)
    commandLineOptions.add_options()
       ( "help,h",
            "Print help message" )
+      ( "version",
+           "Show program version" )
 
       ( "loglevel,L",
            boost::program_options::value<unsigned int>(&logLevel)->default_value(boost::log::trivial::severity_level::info),
@@ -141,6 +144,10 @@ int main(int argc, char** argv)
                  << commandLineOptions;
        return 1;
    }
+   else if(vm.count("version")) {
+      std::cerr << "HPCT Importer" << " " << HPCT_VERSION << "\n";
+      return 0;
+   }
 
    if(importerConfigFile.empty()) {
       std::cerr << "ERROR: No importer configuration file provided!\n";
